@@ -21,7 +21,7 @@ def find_increment(
     # Most important cases are major and minor.
     # Everything else will be considered patch.
     select_pattern = re.compile(regex)
-    increment = None
+    increment: Optional[str] = None
 
     for commit in commits:
         for message in commit.message.split("\n"):
@@ -196,7 +196,9 @@ def _version_to_regex(version: str):
     return re.compile(f"{clean_regex}")
 
 
-def create_tag(version: Union[Version, str], tag_format: Optional[str] = None) -> str:
+def normalize_tag(
+    version: Union[Version, str], tag_format: Optional[str] = None
+) -> str:
     """The tag and the software version might be different.
 
     That's why this function exists.
