@@ -39,11 +39,15 @@ class GitTag(GitObject):
     def __init__(self, name, rev, date):
         self.rev = rev.strip()
         self.name = name.strip()
-        self.date = date.strip()
+        self._date = date.strip()
 
     def __repr__(self):
         return f"GitTag('{self.name}', '{self.rev}', '{self.date}')"
 
+    @property
+    def date(self):
+        return self._date
+
     @classmethod
     def from_line(cls, line: str, inner_delimiter: str) -> "GitTag":
 
@@ -82,10 +86,10 @@ def get_commits(
     )
 
     if start:
-        c = cmd.run(f"{git_log_cmd} {start}..{end}")
+        command = f"{git_log_cmd} {start}..{end}"
     else:
-        c = cmd.run(f"{git_log_cmd} {end}")
-
+        command = f"{git_log_cmd} {end}"
+    c = cmd.run(command)
     if not c.out:
         return []
 
